SMdRQA: Implementing Sliding Window MdRQA to get Summary Statistics Estimate of MdRQA measures from the Data
============================================================================================================

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.10854678.svg
        :target: https://doi.org/10.5281/zenodo.10854678

.. image:: https://img.shields.io/github/license/SwaragThaikkandi/SMdRQA
        :target: https://img.shields.io/github/license/SwaragThaikkandi/SMdRQA/LICENSE

Package integrity
-----------------

.. image:: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/python-package.yml/badge.svg
        :target: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/python-package.yml

.. image:: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/pages/pages-build-deployment/badge.svg
   :target: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/pages/pages-build-deployment
   :alt: pages-build-deployment

PyPI Package Information
------------------------

.. image:: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/python-publish.yml/badge.svg
        :target: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/python-publish.yml

.. image:: https://img.shields.io/pypi/v/SMdRQA
        :target: https://pypi.org/project/SMdRQA/

.. image:: https://img.shields.io/pypi/pyversions/SMdRQA.svg?logo=python&logoColor=FFE873
        :target: https://pypi.python.org/pypi/SMdRQA

.. image:: https://img.shields.io/pypi/format/SMdRQA
        :target: https://pypi.org/project/SMdRQA/

.. image:: https://img.shields.io/pypi/status/SMdRQA
        :target: https://pypi.org/project/SMdRQA/

.. image:: https://img.shields.io/pypi/implementation/SMdRQA
        :target: https://pypi.org/project/SMdRQA/

.. image:: https://img.shields.io/pypi/wheel/SMdRQA
        :target: https://pypi.org/project/SMdRQA/

.. image:: https://static.pepy.tech/badge/SMdRQA
        :target: https://pepy.tech/project/SMdRQA

Security
--------

.. image:: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/github-code-scanning/codeql/badge.svg
        :target: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/github-code-scanning/codeql

.. image:: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/bandit.yml/badge.svg
        :target: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/bandit.yml

.. image:: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/dependency-review.yml/badge.svg
        :target: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/dependency-review.yml

.. image:: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/devskim.yml/badge.svg
        :target: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/devskim.yml

.. image:: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/ossar.yml/badge.svg
        :target: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/ossar.yml

GitHub
------

.. image:: https://img.shields.io/github/v/release/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA/releases

.. image:: https://img.shields.io/github/issues-pr/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA/pulls

.. image:: https://img.shields.io/github/stars/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA/stargazers

.. image:: https://img.shields.io/github/languages/count/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA/languages

.. image:: https://img.shields.io/github/search/:user/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA/search

.. image:: https://img.shields.io/github/languages/top/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA

.. image:: https://img.shields.io/github/languages/code-size/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA

.. image:: https://img.shields.io/github/directory-file-count/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA

.. image:: https://img.shields.io/github/repo-size/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA

.. image:: https://img.shields.io/gitlab/pipeline-status/SwaragThaikkandi/SMdRQA
        :target: https://gitlab.com/SwaragThaikkandi/SMdRQA/pipelines

.. image:: https://img.shields.io/gitlab/pipeline-coverage/SwaragThaikkandi/SMdRQA
        :target: https://gitlab.com/SwaragThaikkandi/SMdRQA/pipelines

.. image:: https://img.shields.io/github/downloads/SwaragThaikkandi/SMdRQA/total
        :target: https://github.com/SwaragThaikkandi/SMdRQA/releases

.. image:: https://img.shields.io/github/discussions/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA/discussions

.. image:: https://img.shields.io/github/created-at/SwaragThaikkandi/SMdRQA
        :target: https://github.com/SwaragThaikkandi/SMdRQA

.. image:: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/label.yml/badge.svg
        :target: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/label.yml

.. image:: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/docs-build.yml/badge.svg
        :target: https://github.com/SwaragThaikkandi/SMdRQA/actions/workflows/docs-build.yml

